Struct MonitorHandle
pub struct MonitorHandle(pub Arc<dyn MonitorHandleProvider>);Expand description
Handle to a monitor.
Allows you to retrieve basic information and metadata about a monitor.
Can be used in Window creation to place the window on a specific
monitor.
This can be retrieved from one of the following methods, which return an
iterator of MonitorHandles:
Platform-specific
Web: A MonitorHandle created without detailed monitor permissions
will always represent the current monitor the browser window is in instead of a specific
monitor.
Tuple Fields
0: Arc<dyn MonitorHandleProvider>Methods from Deref<Target = dyn MonitorHandleProvider>
pub fn cast_ref<T>(&self) -> Option<&T>where
T: MonitorHandleProvider,
pub fn cast_ref<T>(&self) -> Option<&T>where
T: MonitorHandleProvider,
Downcast to the backend concrete type.
Returns None if the object was not from that backend.