VideoMode

Struct VideoMode 

pub struct VideoMode { /* private fields */ }
Describes a fullscreen video mode of a monitor.

Can be acquired with MonitorHandleProvider::video_modes.

Implementations



impl VideoMode

pub fn new( size: PhysicalSize<u32>, bit_depth: Option<NonZero<u16>>, refresh_rate_millihertz: Option<NonZero<u32>>, ) -> VideoMode

pub fn size(&self) -> PhysicalSize<u32>

Returns the resolution of this video mode. This must not be used to create your rendering surface. Use Window::surface_size() instead.

pub fn bit_depth(&self) -> Option<NonZero<u16>>

Returns the bit depth of this video mode, as in how many bits you have available per color. This is generally 24 bits or 32 bits on modern systems, depending on whether the alpha channel is counted or not.

Platform-specific
  • macOS: Video modes do not control the bit depth of the monitor, so this often defaults to 32.
  • iOS: Always returns None.
  • Wayland: Always returns None.

pub fn refresh_rate_millihertz(&self) -> Option<NonZero<u32>>

Returns the refresh rate of this video mode in mHz.